@@ -1,3 +1,3 @@
+class RateLimitedException(Exception):pass
 class BadRequestException(Exception):pass
-class ServerErrorException(Exception):pass
-class RateLimitException(Exception):pass
\ No newline at end of file
+class ServerErrorException(Exception):pass
\ No newline at end of file
